@@ -17,4 +17,7 @@ TAG = 8
 GROUP = 9
 SEARCH_URL = 10
 USER_MESSAGES = 11
+READ = 12
+RETWEET = 13
+LIKE = 14
 GEO_FRIEND_POSITIONS = 50
